yt.utilities.lib.allocation\_container module
=============================================

.. automodule:: yt.utilities.lib.allocation_container
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
